
.. currentmodule:: introspection

Misc. functions
========================================

.. autofunction:: introspection.get_parameters
.. automodule:: introspection.misc
.. autoclass:: introspection.super
